==> question2answer-1.5-language-lt.zip: lt/qa-lang-question.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-question.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for question page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer_title' => '1 Atsakymas',
		'a_convert_to_c_on' => 'Paversti šį atsakymą į komentarą atsakymui:',
		'a_convert_to_c' => 'Paversti šį atsakymą į komentarą atsakymui',
		'a_convert_warn_cs' => 'Įspėjimas: ši diskusija negali būti atšaukta ir taip pat perkels šio atsakymo komentarus.',
		'a_convert_warn' => 'Įspėjimas: ši diskusija negali būti atšaukta.',
		'a_notify_email' => 'Atsiųskite el. laišką šiuo adresu, jei mano atsakymas buvo patvirtintas arba pakomentuotas:',
		'a_notify_label' => 'Atsiųskite el. laišką, jei mano atsakymas buvo patvirtintas arba pakomentuotas',
		'a_notify_x_label' => 'Atsiųskite el. laišką (^), jei mano atsakymas buvo patvirtintas arba pakomentuotas',
		'a_waiting_your_approval' => 'Šis atsakymas laukia jūsų patvirtinimo',
		'a_your_waiting_approval' => 'Jūsų atsakymas neužilgo bus peržiūrėtas ir patvirtintas.',
		'add_answer_button' => 'Pateikti atsakymą',
		'add_comment_button' => 'Komentuoti',
		'add_q_favorites' => 'Pridėti šį klausimą į mano mėgstamiausius',
		'answer_button' => 'atsakyti',
		'answer_limit' => 'Gauta per daug atsakymų - prašom pabandyti už valandos',
		'answer_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte atsakyti į šį klausimą.',
		'answer_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte atsakyti į šį klausimą.',
		'answer_q_popup' => 'Atsakyti į šį klausimą',
		'approve_button' => 'patvirtinti',
		'ask_button' => 'Užduoti klausimą',
		'ask_button_short' => 'Klausti',		
		'ask_follow_from_a' => 'Jūsų klausimas bus susijęs su šiuo atsakymu:',
		'ask_follow_title' => 'Užduoti susijusį klausimą',
		'ask_limit' => 'Gauta per daug klausimų - prašom pabandyti už valandos',
		'ask_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte užduoti klausimą.',
		'ask_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte užduoti klausimą.',
		'ask_same_q' => 'Prieš tęsdami patikrinkite ar jūsų klausimas jau nebuvo užduotas:',
		'ask_title' => 'Užduok klausimą',
		'c_notify_email' => 'Atsiųskite el. laišką šiuo adresu, jei kas nors pakomentavo po manęs:',
		'c_notify_label' => 'Atsiųskite el. laišką, jei kas nors pakomentavo po manęs',
		'c_notify_x_label' => 'Atsiųskite el. laišką (^), jei kas nors pakomentavo po manęs',
		'c_waiting_your_approval' => 'Šis komentaras laukia jūsų patvirtinimo',
		'c_your_waiting_approval' => 'Jūsų komentaras neužilgo bus peržiūrėtas ir patvirtintas.',
		'category_js_note' => 'Tam kad galėtumėte pasirinkti kategoriją, įjunkite Javascript savo interneto naršyklėje.',
		'category_required' => 'Prašom pasirinkti kategoriją',
		'claim_button' => 'Aš parašiau tai',
		'clear_flags_button' => 'pašalinti įspėjimus',
		'clear_flags_popup' => 'Pašalinti visų vartotojų įspėjimus',
		'close_button' => 'uždaryti',
		'close_duplicate_error' => 'Dubliuojančių klausimų nerasta - prašom pabandyti įvesti numerį iš kito klausimo URL adreso, pvz. 123.',
		'close_duplicate' => 'Šis klausimas dubliuoja kitą klausimą',
		'close_form_button' => 'Uždaryti klausimą',
		'close_form_title' => 'Uždaryti šį klausimą',
		'close_original_note' => 'Jūs taip pat galite įvesti numerį iš URL adreso, pvz. 123.',
		'close_original_title' => 'Pirminio klausimo URL adresas:',
		'close_q_popup' => 'Uždaryti šį klausimą naujiems atsakymams',
		'close_reason_title' => 'Šio klausimo uždarymo priežastis:',
		'closed_as_duplicate' => 'uždarytas kaip dublikatas klausimui:',
		'closed_with_note' => 'uždarytas su šia žinute:',
		'comment_a_popup' => 'Pakomentuoti šį atsakymą',
		'comment_button' => 'komentuoti',
		'comment_limit' => 'Gauta per daug komentarų - prašom pabandyti už valandos',
		'comment_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte komentuoti.',
		'comment_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte komentuoti.',
		'comment_on_a' => 'Komentaras atsakymui: ',
		'comment_on_q' => 'Komentaras klausimui: ',
		'comment_q_popup' => 'Pakomentuoti šį klausimą',
		'delete_a_popup' => 'Negrąžinamai ištrinti šį atsakymą',
		'delete_button' => 'ištrinti',
		'delete_c_popup' => 'Negrąžinamai ištrinti šį komentarą',
		'delete_q_popup' => 'Negrąžinamai ištrinti šį klausimą',
		'duplicate_content' => 'Jūsų sukurtas tekstas atrodo yra dublikatas.',
		'edit_a_popup' => 'Redaguoti šį atsakymą',
		'edit_a_title' => 'Redaguoti atsakymą',
		'edit_button' => 'redaguoti',
		'edit_c_popup' => 'Redaguoti šį komentarą',
		'edit_c_title' => 'Redaguoti komentarą',
		'edit_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte redaguoti.',
		'edit_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte redaguoti.',
		'edit_q_popup' => 'Redaguoti šį klausimą',
		'edit_q_title' => 'Redaguoti Klausimą',
		'example_tags' => 'Žymių pavyzdžiai: ',
		'flag_a_popup' => 'Pažymėkite šį atsakymą kaip brukalą arba netinkantį',
		'flag_button' => 'pažymėti kaip netinkantį',
		'flag_c_popup' => 'Pažymėkite šį komentarą kaip brukalą arba netinkantį',
		'flag_hide_button' => 'pažymėti kaip netinkantį ir paslėpti',
		'flag_limit' => 'Per daug įrašų buvo pažymėti kaip netinkantys - prašom pabandyti už valandos',
		'flag_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte įrašus žymėti kaip netinkančius.',
		'flag_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte įrašus žymėti kaip netinkančius.',
		'flag_not_allowed' => 'Negalima žymėti kaip netinkančio',
		'flag_q_popup' => 'Pažymėti šį klausimą kaip brukalą arba netinkantį',
		'follow_a_popup' => 'Klausti naujo klausimo susijusio su šiuo atsakymo',
		'follow_button' => 'klausti susijusio klausimo',
		'follows_a' => 'susijęs su atsakymu klausimui:',
		'follows_q' => 'apie klausimą:',
		'hide_a_popup' => 'Paslėpti šį atsakymą',
		'hide_button' => 'paslėpti',
		'hide_c_popup' => 'Paslėpti šį komentarą',
		'hide_q_popup' => 'Paslėpti šį klausimą',
		'matching_tags' => 'Panašios žymės: ',
		'max_tags_x' => 'Daugiausia ^ žymės yra leidžiamos',
		'min_tags_x' => 'Prašom pateikti bent ^ žymių',
		'notify_email_note' => 'Privatumas: Jūsų el. paštas bus naudojamas tik siunčiant šiuos pranešimus.',
		'q_category_label' => 'Kategorija:',
		'q_content_label' => 'Daugiau informacijos apie klausimą:',
		'q_hidden_author' => 'Šis klausimas buvo paslėptas autoriaus',
		'q_hidden_flagged' => 'Šis klausimas buvo pažymėtas kaip netinkamas ir buvo paslėptas',
		'q_hidden_other' => 'Šis klausimas buvo paslėptas',
		'q_notify_email' => 'Atsiųskite el. laišką šiuo adresu, jei mano atsakymas buvo atsakytas ar pakomentuotas:',
		'q_notify_label' => 'Atsiųskite el. laišką, jei mano atsakymas buvo atsakytas ar pakomentuotas',
		'q_notify_x_label' => 'Atsiųskite el. laišką (^), jei mano atsakymas buvo atsakytas ar pakomentuotas',
		'q_tags_comma_label' => 'Žymės - naudokite kablelį (,) kaip skyriklį:',
		'q_tags_label' => 'Žymės - naudokite brūkšnį žodžių sujungimui:',
		'q_title_label' => 'Klausimas vienu sakiniu:',
		'q_waiting_approval' => 'Šis klausimas laukia patvirtinimo',
		'q_waiting_your_approval' => 'Šis klausimas laukia jūsų patvirtinimo',
		'q_your_waiting_approval' => 'Jūsų klausimas neužilgo bus peržiūrėtas ir patvirtintas.',
		'recat_button' => 'pakeisti kategoriją',
		'recat_popup' => 'Pakeisti šio klausimo kategoriją',
		'recat_q_title' => 'Pakeisti klausimo kategoriją',
		'reject_button' => 'atmesti',
		'remove_q_favorites' => 'Pašalinti šį klausimą iš mano mėgstamiausių',
		'reopen_button' => 'vėl atidaryti',
		'reply_button' => 'atsakyti',
		'reply_c_popup' => 'Atsakyti į šį komentarą',
		'reshow_button' => 'vėl parodyti',
		'retag_button' => 'pakeisti žymes',
		'retag_cat_popup' => 'Pakeisti šio klausimo kategoriją ar žymes',
		'retag_popup' => 'Pakeisti šio klausimo žymes',
		'retag_q_title' => 'Pakeisti klausimo žymes',
		'select_popup' => 'Paspauskite geriausio atsakymo pasirinkimui',
		'select_text' => 'Geriausias atsakymas',
		'show_1_comment' => 'Rodyti 1 komentarą',
		'show_1_previous_comment' => 'Rodyti 1 ankstesnį komentarą',
		'show_x_comments' => 'Rodyti ^ komentarų',
		'show_x_previous_comments' => 'Rodyti ^ ankstesnių komentarų',
		'unflag_button' => 'pašalinti įspėjimą',
		'unflag_popup' => 'Pašalinti įspėjimą, kurį jūs uždėjote',
		'unselect_popup' => 'Paspauskite tam, kad nužymėtumėte',
		'x_answers_title' => '^ Atsakymų',
		'your_answer_title' => 'Jūsų atsakymas',
		'your_comment_a' => 'Jūsų komentaras šiuo atsakymu:',
		'your_comment_q' => 'Jūsų komentaras šiuo klausimu:',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-lt.zip: lt/qa-lang-question.php <==
<?php
/*
	Question2Answer by Gideon Greenspan and contributors
	http://www.question2answer.org/

	File: qa-include/qa-lang-question.php
	Description: Language phrases for question page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer_title' => '1 Atsakymas',
		'a_convert_to_c_on' => 'Paversti šį atsakymą į komentarą atsakymui:',
		'a_convert_to_c' => 'Paversti šį atsakymą į komentarą atsakymui',
		'a_convert_warn' => 'Įspėjimas: ši diskusija negali būti atšaukta.',
		'a_convert_warn_cs' => 'Įspėjimas: ši diskusija negali būti atšaukta ir taip pat perkels šio atsakymo komentarus.',
		'a_notify_email' => 'Atsiųskite el. laišką šiuo adresu, jei mano atsakymas buvo patvirtintas arba pakomentuotas:',
		'a_notify_label' => 'Atsiųskite el. laišką, jei mano atsakymas buvo patvirtintas arba pakomentuotas',
		'a_notify_x_label' => 'Atsiųskite el. laišką (^), jei mano atsakymas buvo patvirtintas arba pakomentuotas',
		'a_waiting_your_approval' => 'Šis atsakymas laukia jūsų patvirtinimo',
		'a_your_waiting_approval' => 'Jūsų atsakymas neužilgo bus peržiūrėtas ir patvirtintas.',
		'add_answer_button' => 'Pateikti atsakymą',
		'add_comment_button' => 'Komentuoti',
		'add_q_favorites' => 'Pridėti šį klausimą į mano mėgstamiausius',
		'anon_name_label' => 'Jūsų rodomas vardas (pasirinktinai):',
		'answer_button' => 'atsakyti',
		'answer_limit' => 'Gauta per daug atsakymų - prašom pabandyti už valandos',
		'answer_must_be_approved' => 'Jūsų paskyra turi būti patvirtinta, tam kad galėtumėte atsakyti į klausimą.',
		'answer_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte atsakyti į šį klausimą.',
		'answer_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte atsakyti į šį klausimą.',
		'answer_q_popup' => 'Atsakyti į šį klausimą',
		'approve_a_popup' => 'Patvirtinti šį atsakymą',
		'approve_button' => 'patvirtinti',
		'approve_c_popup' => 'Patvirtinti šį komentarą',
		'approve_q_popup' => 'Patvirtinti šį klausimą',
		'ask_button' => 'Užduoti klausimą',
		'ask_follow_from_a' => 'Jūsų klausimas bus susijęs su šiuo atsakymu:',
		'ask_follow_title' => 'Užduoti susijusį klausimą',
		'ask_limit' => 'Gauta per daug klausimų - prašom pabandyti už valandos',
		'ask_must_be_approved' => 'Jūsų paskyra turi būti patvirtinta, kad galėtumėte klausti klausimo.',
		'ask_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte užduoti klausimą.',
		'ask_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte užduoti klausimą.',
		'ask_same_q' => 'Prieš tęsdami patikrinkite ar jūsų klausimas jau nebuvo užduotas:',
		'ask_title' => 'Užduok klausimą',
		'c_notify_email' => 'Atsiųskite el. laišką šiuo adresu, jei kas nors pakomentavo po manęs:',
		'c_notify_label' => 'Atsiųskite el. laišką, jei kas nors pakomentavo po manęs',
		'c_notify_x_label' => 'Atsiųskite el. laišką (^), jei kas nors pakomentavo po manęs',
		'c_waiting_your_approval' => 'Šis komentaras laukia jūsų patvirtinimo',
		'c_your_waiting_approval' => 'Jūsų komentaras neužilgo bus peržiūrėtas ir patvirtintas.',
		'category_ask_not_allowed' => 'Jūs neturite teisių klausti klausimų šioje kategorijoje',
		'category_js_note' => 'Tam kad galėtumėte pasirinkti kategoriją, įjunkite Javascript savo interneto naršyklėje.',
		'category_required' => 'Prašom pasirinkti kategoriją',
		'claim_a_popup' => 'Priskirti šį atsakymą prie savo paskyros',
		'claim_button' => 'Aš parašiau tai',
		'claim_c_popup' => 'Priskirti šį komentarą prie savo paskyros',
		'claim_q_popup' => 'Priskirti šį klausimą prie savo paskyros',
		'clear_flags_button' => 'pašalinti įspėjimus',
		'clear_flags_popup' => 'Pašalinti visų vartotojų įspėjimus',
		'close_button' => 'uždaryti',
		'close_duplicate' => 'Šis klausimas dubliuoja kitą klausimą',
		'close_duplicate_error' => 'Dubliuojančių klausimų nerasta - prašom pabandyti įvesti numerį iš kito klausimo URL adreso, pvz. 123.',
		'close_form_button' => 'Uždaryti klausimą',
		'close_form_title' => 'Uždaryti šį klausimą',
		'close_original_note' => 'Jūs taip pat galite įvesti numerį iš URL adreso, pvz. 123.',
		'close_original_title' => 'Pirminio klausimo URL adresas:',
		'close_q_popup' => 'Uždaryti šį klausimą naujiems atsakymams',
		'close_reason_title' => 'Šio klausimo uždarymo priežastis:',
		'closed_as_duplicate' => 'uždarytas kaip dublikatas klausimui:',
		'closed_with_note' => 'uždarytas su šia žinute:',
		'comment_a_popup' => 'Pakomentuoti šį atsakymą',
		'comment_button' => 'komentuoti',
		'comment_limit' => 'Gauta per daug komentarų - prašom pabandyti už valandos',
		'comment_must_be_approved' => 'Jūsų paskyra turi būti patvirtinta, tam kad galėtumėte parašyti komentarą.',
		'comment_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte komentuoti.',
		'comment_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte komentuoti.',
		'comment_on_a' => 'Komentaras atsakymui: ',
		'comment_on_q' => 'Komentaras klausimui: ',
		'comment_q_popup' => 'Pakomentuoti šį klausimą',
		'delete_a_popup' => 'Negrąžinamai ištrinti šį atsakymą',
		'delete_button' => 'ištrinti',
		'delete_c_popup' => 'Negrąžinamai ištrinti šį komentarą',
		'delete_q_popup' => 'Negrąžinamai ištrinti šį klausimą',
		'duplicate_content' => 'Jūsų sukurtas tekstas atrodo yra dublikatas.',
		'edit_a_popup' => 'Redaguoti šį atsakymą',
		'edit_a_title' => 'Redaguoti atsakymą',
		'edit_button' => 'redaguoti',
		'edit_c_popup' => 'Redaguoti šį komentarą',
		'edit_c_title' => 'Redaguoti komentarą',
		'edit_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte redaguoti.',
		'edit_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte redaguoti.',
		'edit_q_popup' => 'Redaguoti šį klausimą',
		'edit_q_title' => 'Redaguoti Klausimą',
		'example_tags' => 'Žymių pavyzdžiai: ',
		'flag_a_popup' => 'Pažymėkite šį atsakymą kaip brukalą arba netinkantį',
		'flag_button' => 'pažymėti kaip netinkantį',
		'flag_c_popup' => 'Pažymėkite šį komentarą kaip brukalą arba netinkantį',
		'flag_hide_button' => 'pažymėti kaip netinkantį ir paslėpti',
		'flag_limit' => 'Per daug įrašų buvo pažymėti kaip netinkantys - prašom pabandyti už valandos',
		'flag_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte įrašus žymėti kaip netinkančius.',
		'flag_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte įrašus žymėti kaip netinkančius.',
		'flag_not_allowed' => 'Negalima žymėti kaip netinkančio',
		'flag_q_popup' => 'Pažymėti šį klausimą kaip brukalą arba netinkantį',
		'follow_a_popup' => 'Klausti naujo klausimo susijusio su šiuo atsakymo',
		'follow_button' => 'klausti susijusio klausimo',
		'follows_a' => 'susijęs su atsakymu klausimui:',
		'follows_q' => 'apie klausimą:',
		'hide_a_popup' => 'Paslėpti šį atsakymą',
		'hide_button' => 'paslėpti',
		'hide_c_popup' => 'Paslėpti šį komentarą',
		'hide_q_popup' => 'Paslėpti šį klausimą',
		'matching_tags' => 'Panašios žymės: ',
		'max_tags_x' => 'Daugiausia ^ žymės yra leidžiamos',
		'min_tags_x' => 'Prašom pateikti bent ^ žymių',
		'notify_email_note' => 'Privatumas: Jūsų el. paštas bus naudojamas tik siunčiant šiuos pranešimus.',
		'q_category_label' => 'Kategorija:',
		'q_content_label' => 'Daugiau informacijos apie klausimą:',
		'q_hidden_author' => 'Šis klausimas buvo paslėptas autoriaus',
		'q_hidden_flagged' => 'Šis klausimas buvo pažymėtas kaip netinkamas ir buvo paslėptas',
		'q_hidden_other' => 'Šis klausimas buvo paslėptas',
		'q_notify_email' => 'Atsiųskite el. laišką šiuo adresu, jei mano atsakymas buvo atsakytas ar pakomentuotas:',
		'q_notify_label' => 'Atsiųskite el. laišką, jei mano atsakymas buvo atsakytas ar pakomentuotas',
		'q_notify_x_label' => 'Atsiųskite el. laišką (^), jei mano atsakymas buvo atsakytas ar pakomentuotas',
		'q_tags_comma_label' => 'Žymės - naudokite kablelį (,) kaip skyriklį:',
		'q_tags_label' => 'Žymės - naudokite brūkšnį žodžių sujungimui:',
		'q_title_label' => 'Klausimas vienu sakiniu:',
		'q_waiting_approval' => 'Šis klausimas laukia patvirtinimo',
		'q_waiting_your_approval' => 'Šis klausimas laukia jūsų patvirtinimo',
		'q_your_waiting_approval' => 'Jūsų klausimas neužilgo bus peržiūrėtas ir patvirtintas.',
		'recat_button' => 'pakeisti kategoriją',
		'recat_popup' => 'Pakeisti šio klausimo kategoriją',
		'recat_q_title' => 'Pakeisti klausimo kategoriją',
		'reject_a_popup' => 'Atmesti šį atsakymą',
		'reject_button' => 'atmesti',
		'reject_c_popup' => 'Atmesti šį komentarą',
		'reject_q_popup' => 'Atmesti šį klausimą',
		'remove_q_favorites' => 'Pašalinti šį klausimą iš mano mėgstamiausių',
		'reopen_button' => 'vėl atidaryti',
		'reopen_q_popup' => 'Vėl atidaryti šį klausimą',
		'reply_button' => 'atsakyti',
		'reply_c_popup' => 'Atsakyti į šį komentarą',
		'reshow_a_popup' => 'Vėl parodyti šį klausimą',
		'reshow_button' => 'vėl parodyti',
		'reshow_c_popup' => 'Vėl parodyti šį komentarą',
		'reshow_q_popup' => 'Vėl parodyti šį klausimą',
		'retag_button' => 'pakeisti žymes',
		'retag_cat_popup' => 'Pakeisti šio klausimo kategoriją ar žymes',
		'retag_popup' => 'Pakeisti šio klausimo žymes',
		'retag_q_title' => 'Pakeisti klausimo žymes',
		'save_silent_label' => 'Išsaugoti tyliai kad nesimatytų jog buvo redaguota',
		'select_popup' => 'Paspauskite geriausio atsakymo pasirinkimui',
		'select_text' => 'Geriausias atsakymas',
		'show_1_comment' => 'Rodyti 1 komentarą',
		'show_1_previous_comment' => 'Rodyti 1 ankstesnį komentarą',
		'show_x_comments' => 'Rodyti ^ komentarų',
		'show_x_previous_comments' => 'Rodyti ^ ankstesnių komentarų',
		'unflag_button' => 'pašalinti įspėjimą',
		'unflag_popup' => 'Pašalinti įspėjimą, kurį jūs uždėjote',
		'unselect_popup' => 'Paspauskite tam, kad nužymėtumėte',
		'x_answers_title' => '^ Atsakymų',
		'your_answer_title' => 'Jūsų atsakymas',
		'your_comment_a' => 'Jūsų komentaras šiuo atsakymu:',
		'your_comment_q' => 'Jūsų komentaras šiuo klausimu:',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
